@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: EphyAboutModule.cpp 7956 2008-02-17 17:56:33Z chpe $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -432,8 +432,8 @@ EphyAboutModule::GetErrorMessage(nsIURI *aURI,
 		/* Error is a bit too strong here */
 		*aStockIcon = GTK_STOCK_DIALOG_INFO;
 
-		*aTitle = g_strdup (_("Cannot Load Document Whilst Working Offline"));
-		*aPrimary = g_strdup (_("Cannot load document whilst working offline."));
+		*aTitle = g_strdup (_("Cannot Load Document While Working Offline"));
+		*aPrimary = g_strdup (_("Cannot load document while working offline."));
 		*aSecondary = g_strdup (_("To view this document, disable “Work Offline” and try again."));
 	}
 	else if (strcmp (aError, "deniedPortAccess") == 0)
