@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: mozilla-embed-single.cpp 8287 2008-06-21 11:25:43Z jmouette $
+ *  $Id$
  */
 
 #include "mozilla-config.h"
@@ -925,14 +925,17 @@ impl_list_passwords (EphyPasswordManager *manager)
 
 #ifdef HAVE_GECKO_1_9
 	nsILoginInfo **logins = nsnull;
-	PRUint32 count,i;
+	PRUint32 count = 0,i;
 	nsresult rv;
 
 	nsCOMPtr<nsILoginManager> loginManager =
 			do_GetService (NS_LOGINMANAGER_CONTRACTID);
 	NS_ENSURE_TRUE (loginManager, NULL);
 
-	loginManager -> GetAllLogins(&count, &logins);
+	rv = loginManager -> GetAllLogins(&count, &logins);
+	if (NS_FAILED (rv))
+		return NULL;
+	NS_ENSURE_TRUE (logins, NULL);
 
 	for (i=0; i < count; i++) {
 		nsString transfer;
