@@ -15,13 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-password-dialog.h 6952 2007-03-11 19:42:02Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_PASSWORD_DIALOG_H
 #define EPHY_PASSWORD_DIALOG_H
 
-#include <gtk/gtkmessagedialog.h>
+#include <gtk/gtk.h>
 #include <libgnomeui/gnome-password-dialog.h>
 
 G_BEGIN_DECLS
