@@ -13,15 +13,15 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-bookmarks-editor.h 6589 2006-09-13 11:49:01Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_BOOKMARKS_EDITOR_H
 #define EPHY_BOOKMARKS_EDITOR_H
 
-#include <gtk/gtkdialog.h>
+#include <gtk/gtk.h>
 
 #include "ephy-node-view.h"
 #include "ephy-bookmarks.h"
